@@ -3,6 +3,8 @@ build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
+ 'ALIGNOF_LONG': 8,
+ 'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
  'AR': '/usr/bin/xcrun ar',
@@ -10,8 +12,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/bin',
- 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9',
+ 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/bin',
+ 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
  'BLDLIBRARY': '',
  'BLDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ',
  'BUILDEXE': '',
@@ -29,19 +31,19 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CPPFLAGS': '-I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk',
  'CONFIGURE_LDFLAGS': '-L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ',
  'CONFIGURE_LDFLAGS_NODIST': '-flto -Wl,-export_dynamic -g',
- 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' '--with-ensurepip=no' '--with-system-expat' '--with-system-ffi' '--enable-optimizations' '--with-lto' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ' 'LDFLAGS=-L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ' 'CPPFLAGS=-I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk'",
- 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/include',
- 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/include/python3.9',
+ 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' '--with-ensurepip=no' '--with-readline=editline' '--with-system-expat' '--with-system-ffi' '--enable-optimizations' '--with-lto' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ' 'LDFLAGS=-L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ' 'CPPFLAGS=-I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk'",
+ 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include',
+ 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24/coverage.info',
- 'COVERAGE_REPORT': '/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24/lcov-report',
+ 'COVERAGE_INFO': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19/coverage.info',
+ 'COVERAGE_REPORT': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -I./Include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk',
  'CXX': '/usr/bin/clang++',
- 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9 /opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9 /opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9/lib-dynload',
- 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9',
+ 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10 /opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10 /opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/lib-dynload',
+ 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9/lib-dynload',
+ 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
@@ -61,11 +63,12 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPERIMENTAL_ISOLATED_SUBINTERPRETERS': 0,
  'EXPORTSFROM': '',
  'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-39-darwin.so',
+ 'EXT_SUFFIX': '.cpython-310-darwin.so',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
@@ -103,6 +106,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CLOCK_GETRES': 1,
  'HAVE_CLOCK_GETTIME': 1,
  'HAVE_CLOCK_SETTIME': 1,
+ 'HAVE_CLOSE_RANGE': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
@@ -155,6 +159,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
+ 'HAVE_EVENTFD': 0,
  'HAVE_EXECV': 1,
  'HAVE_EXPLICIT_BZERO': 0,
  'HAVE_EXPLICIT_MEMSET': 0,
@@ -392,6 +397,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SOCKADDR_STORAGE': 1,
  'HAVE_SOCKETPAIR': 1,
  'HAVE_SPAWN_H': 1,
+ 'HAVE_SPLICE': 0,
  'HAVE_SSIZE_T': 1,
  'HAVE_STATVFS': 1,
  'HAVE_STAT_TV_NSEC': 0,
@@ -400,7 +406,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
- 'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
@@ -428,6 +433,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_ENDIAN_H': 0,
  'HAVE_SYS_EPOLL_H': 0,
+ 'HAVE_SYS_EVENTFD_H': 0,
  'HAVE_SYS_EVENT_H': 1,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_IOCTL_H': 1,
@@ -488,6 +494,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_GENERATE_TIME_SAFE': 0,
  'HAVE_UUID_H': 0,
  'HAVE_UUID_UUID_H': 1,
+ 'HAVE_VFORK': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -499,44 +506,44 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
- 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-apple-darwin18.7.0',
- 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/include /opt/local/Library/Frameworks/Python.framework/Versions/3.9/include /opt/local/Library/Frameworks/Python.framework/Versions/3.9/include/python3.9 /opt/local/Library/Frameworks/Python.framework/Versions/3.9/include/python3.9',
- 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/include',
- 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/include/python3.9',
+ 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include /opt/local/Library/Frameworks/Python.framework/Versions/3.10/include /opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10 /opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10',
+ 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include',
+ 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/include/python3.10',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'Python.framework/Versions/3.9/Python',
+ 'INSTSONAME': 'Python.framework/Versions/3.10/Python',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': '/usr/bin/clang++ -bundle -undefined dynamic_lookup',
  'LDFLAGS': '-L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ',
- 'LDLIBRARY': 'Python.framework/Versions/3.9/Python',
+ 'LDLIBRARY': 'Python.framework/Versions/3.10/Python',
  'LDLIBRARYDIR': '',
  'LDSHARED': '/usr/bin/clang -bundle -undefined dynamic_lookup -L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ',
- 'LDVERSION': '3.9',
+ 'LDVERSION': '3.10',
  'LIBC': '',
- 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9',
- 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib',
+ 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
+ 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib',
  'LIBFFI_INCLUDEDIR': '/opt/local/include',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/pkgconfig',
- 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9/config-3.9-darwin',
+ 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/pkgconfig',
+ 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/config-3.10-darwin',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.9.a',
+ 'LIBRARY': 'libpython3.10.a',
+ 'LIBRARY_DEPS': 'libpython3.10.a Python.framework/Versions/3.10/Python',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': ' -ldl   -framework CoreFoundation',
- 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LIBS': '-ldl   -framework CoreFoundation',
+ 'LIBSUBDIRS': 'asyncio \\',
  'LINKCC': '/usr/bin/clang',
- 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9/config-3.9-darwin -lpython3.9 -ldl -framework CoreFoundation',
+ 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10/config-3.10-darwin -lpython3.10 -ldl -framework CoreFoundation',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
@@ -546,18 +553,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'darwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib/python3.9',
+ 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib/python3.10',
  'MACOSX_DEPLOYMENT_TARGET': '10.14',
  'MAINCC': '/usr/bin/clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/share/man',
+ 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/share/man',
  'MKDIR_P': './install-sh -c -d',
- 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  _operator  _collections  _abc  itertools  atexit  _signal  _stat  time  _thread  _locale  _io  faulthandler  _tracemalloc  _peg_parser  _symtable  xxsubtype',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  _operator  _collections  _abc  itertools  atexit  _signal  _stat  time  _thread  _locale  _io  faulthandler  _tracemalloc  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/_abc.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  Modules/timemodule.o  Modules/_threadmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  Modules/_tracemalloc.o  Modules/_peg_parser.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/_abc.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  Modules/timemodule.o  Modules/_threadmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  Modules/_tracemalloc.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'darwin',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"darwin\\"',
@@ -567,6 +574,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '-I/opt/local/libexec/openssl3/include',
  'OPENSSL_LDFLAGS': '-L/opt/local/libexec/openssl3/lib',
  'OPENSSL_LIBS': '-lssl -lcrypto',
+ 'OPENSSL_RPATH': '',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -576,7 +584,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
@@ -584,7 +592,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo',
+ 'PROFILE_TASK': '-m test --pgo --timeout=1200',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 0,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -597,6 +605,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '/opt/local/Library/Frameworks',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
+ 'PYTHON_FOR_REGEN': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
@@ -607,6 +616,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -pipe -Os -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk  -flto -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -fvisibility=hidden -fprofile-instr-use=code.profclangd -I./Include/internal -I. -I./Include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk  -flto -Wl,-export_dynamic -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/opt/local/include -isysroot/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk',
+ 'PY_ENABLE_SHARED': 0,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/opt/local/lib -Wl,-headerpad_max_install_names -Wl,-syslibroot,/Library/Developer/CommandLineTools/SDKs/MacOSX10.14.sdk ',
  'PY_LDFLAGS_NODIST': '-flto -Wl,-export_dynamic -g',
@@ -621,11 +631,11 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24',
- 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/lib',
+ 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19',
+ 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
- 'SHLIBS': ' -ldl   -framework CoreFoundation',
+ 'SHLIBS': '-ldl   -framework CoreFoundation',
  'SHLIB_SUFFIX': '.so',
  'SHM_NEEDS_LIBRT': 0,
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
@@ -648,9 +658,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-39-darwin',
- 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-310-darwin',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
+ 'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -662,33 +673,38 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24 ./python',
+ 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24 ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19 ./python ./Tools/scripts/run_tests.py',
+ 'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
+ 'TEST_MODULES': 'yes',
+ 'THREAD_STACK_SIZE': '0x1000000',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': './Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'VERSION': '3.9',
+ 'VERSION': '3.10',
+ 'WHEEL_PKG_DIR': '',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 1,
+ 'WITH_EDITLINE': 1,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 1,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24',
- 'abs_srcdir': '/opt/local/var/macports/build/python39-4ebbc61c/work/Python-3.9.24',
- 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9/share',
- 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9',
- 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.9',
+ 'abs_builddir': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19',
+ 'abs_srcdir': '/opt/local/var/macports/build/python310-4c74a76c/work/Python-3.10.19',
+ 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10/share',
+ 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10',
+ 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.10',
  'srcdir': '.'}
